import { API_ENDPOINT, CachedPlayer, CachedUsernameToUuid } from "..";
import WebRequest from "../common/WebRequest";

const playerEndpoint = API_ENDPOINT + "/player/{id}";
const playerUsernameToUuidEndpoint = API_ENDPOINT + "/player/uuid/{id}";
const playerSkinPartEndpoint = API_ENDPOINT + "/player/{part}/{id}";

/**
 * Gets information about a Minecraft player.
 *
 * @param id the id of the player
 * @returns the player information, or null if the player does not exist
 */
export function getPlayer(id: string): Promise<CachedPlayer> {
  return WebRequest.get<CachedPlayer>(playerEndpoint.replace("{id}", id));
}

/**
 * Gets the UUID of a Minecraft player.
 *
 * @param id the id of the player
 * @returns the player's UUID, or null if the player does not exist
 */
export function getPlayerUuid(id: string): Promise<CachedUsernameToUuid> {
  return WebRequest.get<CachedUsernameToUuid>(playerUsernameToUuidEndpoint.replace("{id}", id));
}

/**
 * Gets a part of a Minecraft player's skin.
 *
 * @param part the part of the skin
 * @param id the id of the player
 * @returns the player's skin part, or null if the player does not exist
 */
export function getPlayerSkinPart(part: string, id: string): Promise<Buffer> {
  return WebRequest.get<Buffer>(playerSkinPartEndpoint.replace("{part}", part).replace("{id}", id));
}
